<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet
  exclude-result-prefixes="xd exsl estr edate a fo local rng tei teix"
  xpath-default-namespace="http://www.tei-c.org/ns/1.0"
  extension-element-prefixes="exsl estr edate" version="2.0"
  xmlns:a="http://relaxng.org/ns/compatibility/annotations/1.0"
  xmlns:edate="http://exslt.org/dates-and-times"
  xmlns:estr="http://exslt.org/strings" xmlns:exsl="http://exslt.org/common"
  xmlns:fo="http://www.w3.org/1999/XSL/Format"
  xmlns:html="http://www.w3.org/1999/xhtml"
  xmlns:local="http://www.pantor.com/ns/local"
  xmlns:rng="http://relaxng.org/ns/structure/1.0"
  xmlns:tei="http://www.tei-c.org/ns/1.0"
  xmlns:teix="http://www.tei-c.org/ns/Examples"
  xmlns:xd="http://www.pnp-software.com/XSLTdoc"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <!-- This "shoemakers.xsl" version is a version of Mike Poston's "emed.xsl" from 2017-06-28 that -->
  <!-- has been modified by Mike himself and Syd Bauman for the use of the "Shoemaker" and "Holland" -->
  <!-- groups of the Folger EMED Workshop (Shaun Nowicki, Emily Johnson, Linda Braus; -->
  <!-- Promise Li, Phuong-Nghi Pham, Sarah McKeever). -->
  <!-- Only significant change: allow <note>s to point to <seg>s, too. -->
  <xd:doc type="stylesheet">
    <xd:short> TEI stylesheet for Folger Digital Texts. </xd:short>
    <xd:detail> This library is free software; you can redistribute it and/or
      modify it under the terms of the GNU Lesser General Public License as
      published by the Free Software Foundation; either version 2.1 of the
      License, or (at your option) any later version. This library is
      distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
      without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
      PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
      details. You should have received a copy of the GNU Lesser General Public
      License along with this library; if not, write to the Free Software
      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA </xd:detail>
  </xd:doc>
  <xsl:output method="html" encoding="UTF-8"/>
<xsl:strip-space elements="*"/>
<xsl:preserve-space elements="tei:c"/>
  <xsl:template match="/">
	<html>
	<head>
	  <title><xsl:value-of select="//tei:teiHeader/tei:fileDesc/tei:titleStmt/tei:title"/></title>
    <meta http-equiv="X-UA-Compatible" content="IE=edge" />
  <script>
    var path = ""; 
    // path = "/sites/default/files/folger_encodings/html/";
    document.write('<link id="emed-css" rel="stylesheet" type="text/css" href="emed-reg.css"/>\n');
    function changeRdg(rdg) {
      var link = document.getElementById("emed-css");
      if (rdg == "reg-EMED") {
        link.href = path + "emed-reg.css";
      } else {
        link.href = path + "emed.css";
      }
    }
  </script>
	</head>
  <body>
          <div id="pageBlock" class="pageBlock">
            <div class="textBlock">
	            <xsl:apply-templates/>
            </div>
<div id="selector" class="noprint">
<xsl:variable name="idno" select="//tei:idno[@type='EMED']" />
  Choose Spelling:<br/><select id="rdg" onchange="changeRdg(this.value);"><option value="orig-EMED">Original</option><option value="reg-EMED" selected="selected">Regularized</option></select>
<br/>
<br/>
First printed edition:<br/>
<a class="ingoing" href="/{$idno}">
<xsl:value-of select="//tei:fileDesc/tei:titleStmt/tei:title"/>
</a>
</div>
          </div>
        </body>
        </html>
  </xsl:template>

  <xsl:template name="front">
    <xsl:apply-templates select="//tei:front/tei:div"/>
  </xsl:template>
    
  <xsl:variable name="rdg" select="'lemma'" />

  <xsl:template match="tei:teiHeader">
    <xsl:apply-templates select="//tei:titleStmt"/>
    <xsl:apply-templates select="//tei:particDesc"/>
  </xsl:template>

  <xsl:template match="tei:titleStmt">
  </xsl:template>


  <xsl:template match="tei:pb">
    <a name="p{@n}" class="page"/>
    <hr class="noprint pageBorder"/>
    <span class="pageFacs">
      img: <xsl:value-of select="@facs"/>
    <br/>
    sig: <xsl:value-of select="@n"/>
  </span>
    <br/>
  </xsl:template>
  
  <xsl:template match="tei:cb">
    <h2>column: <xsl:value-of select="@facs"/></h2>
    <!--
    <hr class="noprint pageBorder"/><br/>
    <span class="pageFacs">col: <xsl:value-of select="@facs"/></span>
    -->
  </xsl:template>
  
  <xsl:template match="tei:w|tei:c|tei:pc| tei:w/tei:seg | tei:anchor">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <xsl:variable name="note" select="key('noteTargets',@xml:id)" />
    <xsl:variable name="class2">
      <xsl:if test="count($note)">has_textual_note</xsl:if>
    </xsl:variable>
    <xsl:choose>
    <!--
    <xsl:when test="contains(@ana,'zz')"> 
      <span id="{@xml:id}" title="{@n}" class="gap {$class} {$class2}"><xsl:apply-templates/></span>
    </xsl:when>
    <xsl:when test="contains(.,'〈◊〉')"> 
      <span id="{@xml:id}" title="{@n}" class="gap {$class} {$class2}"><xsl:apply-templates/></span>
    </xsl:when>

      <a href="#{$note/@xml:id}"><span id="{@xml:id}" class="{$class} {$class2}"><xsl:apply-templates/></span></a>
    -->
    <xsl:when test="count($note)"> 
      <a href="#note-{@xml:id}"><span id="{@xml:id}" class="{$class} {$class2}"><xsl:apply-templates/></span></a>
    </xsl:when>
    <xsl:otherwise>
      <span id="{@xml:id}" title="{@n}" class="{$class} {$class2}"><xsl:apply-templates/></span>
    </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="tei:metamark">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span title="{@n}" class="mark {$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="tei:metamark[@function='quotation']">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span title="{@n}" class="{$class}"><xsl:apply-templates/></span>
  </xsl:template>

  <xsl:template match="tei:orig">
    <xsl:variable name="class">
      <xsl:if test="contains(@resp,'#EMED')">orig-EMED </xsl:if>
      <xsl:if test="contains(@resp,'#SHC')">orig-SHC </xsl:if>
      <xsl:if test="contains(@resp,'#TCP')">orig-TCP </xsl:if>
    </xsl:variable>
    <span class="rdg {$class}"><xsl:apply-templates/></span>
    <xsl:if test="contains(@resp,'#EMED') and ancestor::tei:pc[not(tei:choice/tei:reg[contains(@resp,'#EMED')])]">
      <span class="rdg reg-EMED"><xsl:apply-templates/></span>
    </xsl:if>
  </xsl:template>
  <xsl:template match="tei:reg">
    <xsl:variable name="class">
      <xsl:if test="contains(@resp,'#EMED')">reg-EMED </xsl:if>
      <xsl:if test="contains(@resp,'#SHC')">reg-SHC </xsl:if>
      <xsl:if test="contains(@resp,'#TCP')">reg-TCP </xsl:if>
    </xsl:variable>
    <span class="rdg {$class}"><xsl:apply-templates/></span>
  </xsl:template>

  <xsl:template match="tei:speaker|tei:seg">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <xsl:variable name="note" select="key('noteTargets',@xml:id)" />
    <xsl:choose>
    <xsl:when test="count($note)"> 
      <a href="#note-{@xml:id}"><span id="{@xml:id}" class="{local-name()} {$class}"><xsl:apply-templates/></span></a>
    </xsl:when>
    <xsl:otherwise>
      <span class="{local-name()} {$class}"><xsl:apply-templates/></span>
    </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="tei:lb">
    <xsl:variable name="class">
      <xsl:if test="contains(@break,'no')">orig-EMED </xsl:if>
      <xsl:if test="contains(@break,'orig')">orig-EMED </xsl:if>
      <xsl:if test="contains(@break,'reg')">reg-EMED </xsl:if>
    </xsl:variable>
    <span class="rdg {$class}"><br/></span>
    <xsl:if test="@n">
      <span class="ln {$class}">ln <xsl:value-of select="substring(concat('0000',@n),string-length(@n)+1)"/></span>
    </xsl:if>
  </xsl:template>

  <!--
  <xsl:template match="tei:div[@type='play']//tei:lb">
  -->
  <xsl:template match="tei:body//tei:lb">
    <xsl:variable name="class">
      <xsl:if test="contains(@break,'no')">orig-EMED </xsl:if>
      <xsl:if test="contains(@break,'orig')">orig-EMED </xsl:if>
      <xsl:if test="contains(@break,'reg')">reg-EMED </xsl:if>
    </xsl:variable>
    <span class="rdg {$class}"><br/></span>
    <xsl:if test="@n">
      <span class="ln {$class}">wln <xsl:value-of select="substring(concat('0000',@n),string-length(@n)+1)"/></span>
      <!--
      <span class="pageFacs">WLN <xsl:value-of select="substring(string-join('0000',@n),-4)"/></span>
-->
    </xsl:if>
  </xsl:template>


  <xsl:template match="tei:stage">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <xsl:variable name="placement">
      <xsl:choose>
      <xsl:when test="contains(@rend,'inline')">inline</xsl:when>
      <xsl:when test="contains(@rend,'leftNote')">leftNote</xsl:when>
      <xsl:when test="contains(@rend,'rightNote')">rightNote</xsl:when>
      <xsl:when test="contains(@rend,'leftMargin')">leftMargin</xsl:when>
      <xsl:when test="contains(@rend,'rightMargin')">rightMargin</xsl:when>
      <xsl:when test="contains(@rend,'left')">left</xsl:when>
      <xsl:when test="contains(@rend,'right')">right</xsl:when>
      <xsl:when test="contains(@rend,'centered')">centered</xsl:when>
      <xsl:when test="contains(@type,'entrance')">centered</xsl:when>
      <xsl:otherwise>right</xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="note" select="key('noteTargets',@xml:id)" />
    <xsl:choose>
    <xsl:when test="count($note)"> 
      <a href="#note-{@xml:id}"><span id="{@xml:id}" class="stage {$placement} {$class}"><xsl:apply-templates/></span></a>
    </xsl:when>
    <xsl:otherwise>
      <span class="stage {$placement} {$class}"><xsl:apply-templates/></span>
    </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <!--
  <xsl:template match="tei:stage">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="stage right {$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="tei:stage[@type='entrance']">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="stage centered {$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="tei:stage[contains(@rend,'centered')]">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="stage centered {$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="tei:stage[contains(@rend,'left')]">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="stage left {$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="tei:stage[contains(@rend,'right')]">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="stage right {$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="tei:stage[contains(@rend,'rightMargin')]">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <div class="stage rightMargin {$class}"><xsl:apply-templates/></div>
  </xsl:template>
  <xsl:template match="tei:stage[contains(@rend,'leftMargin')]">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <div class="stage leftMargin {$class}"><xsl:apply-templates/></div>
  </xsl:template>
  <xsl:template match="tei:stage[contains(@rend,'inline')]">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="stage inline {$class}"><xsl:apply-templates/></span>
  </xsl:template>
  -->
  <xsl:template match="tei:sp/tei:stage[contains(@rend,'inline')]">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="stage spkStage {$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="tei:stage/tei:stage">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="{$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="tei:stage[substring(@xml:id, string-length(@xml:id))='t']">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="alignment stump">&#160;</span>
    <span class="stage {$class}"><xsl:apply-templates/></span>
  </xsl:template>

  <xsl:template match="tei:head">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="head centered {$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="tei:label">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="head centered {$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="tei:label[contains(@rend,'right')] | tei:label[contains(@rend,'left')] | tei:label[contains(@rend,'inline')]">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="{$class}"><xsl:apply-templates/></span>
  </xsl:template>

  <xsl:template match="tei:closer">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="right {$class}"><xsl:apply-templates/></span>
  </xsl:template>

  <xsl:template match="tei:name">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="name italic {$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="*[contains(@rend,'italic')]//tei:name">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="name roman {$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="tei:stage//tei:name">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="name roman {$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="tei:stage[contains(@rend,'roman')]//tei:name">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="name italic {$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="tei:foreign//tei:name">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="name roman {$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="tei:hi//tei:name">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="name roman {$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="*[contains(@rend,'italic')]/tei:name">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="name roman {$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="*[contains(@rend,'roman')]/tei:name">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="name italic {$class}"><xsl:apply-templates/></span>
  </xsl:template>


  <xsl:template match="tei:foreign">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="foreign italic {$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="tei:sup">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="{$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="tei:hi">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="hi italic {$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="tei:hi[@rend='superscript']">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="{$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="tei:seg[@rend='italic']">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="italic {$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="tei:p">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <p style="white-space: normal;" class="{if ( @rend eq 'italic') then @rend else ''} {$class}"><xsl:apply-templates/></p>
  </xsl:template>
  <xsl:template match="p" mode="prose">
    <p style="white-space: normal;"><xsl:apply-templates/></p>
  </xsl:template>
  <xsl:template match="list" mode="prose">
    <span style="text-align: left; font-weight: bold;"><xsl:value-of select="head"/></span>
    <!--<xsl:element name="h{count(ancestor::list|ancestor::div)+1}"><xsl:apply-templates select="head"/></xsl:element>-->
    <ul>
      <xsl:apply-templates select="item" mode="#current"/>
    </ul>
  </xsl:template>
  <xsl:template mode="prose" match="item">
    <li><xsl:apply-templates mode="#current"/></li>
  </xsl:template>

  <xsl:template match="tei:seg[@subtype='closing']">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="closing {$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="tei:seg[@subtype='refrain']">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="indentRefrain {$class}"><xsl:apply-templates/></span>
  </xsl:template>

  <xsl:template match="tei:trailer">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="trailer right {$class}"><xsl:apply-templates/></span>
  </xsl:template>

  <xsl:template match="tei:note">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="note {$class}"><xsl:apply-templates/></span>
  </xsl:template>

  <xsl:template match="tei:div">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <!--
    <span class="divType"><xsl:value-of select="@type"/></span>
    -->
    <span class="{$class}"><xsl:apply-templates/></span>
    <!--
    <br/>
    -->
  </xsl:template>
  <xsl:template match="tei:div[@type='title_page']">
    <!--
    <span class="divType"><xsl:value-of select="@type"/></span>
    -->
    <div class="centered"><xsl:apply-templates/></div><br/>
  </xsl:template>
  <xsl:template match="tei:gap">
    <span class="gap">
      <xsl:text>[</xsl:text>
      <xsl:variable name="display">
        <xsl:choose>
          <xsl:when test="@unit='words'"><xsl:value-of select="'&#9671;'"/></xsl:when>
          <xsl:when test="@reason='missing'"><xsl:value-of select="'*'"/></xsl:when>
          <xsl:when test="@reason='trimmed'"><xsl:value-of select="'*'"/></xsl:when>
          <xsl:when test="@reason='illegible'"><xsl:value-of select="'&#183;'"/></xsl:when>
        <!--
          <xsl:when test="@reason='illegible'">&middot;</xsl:when>
-->
          <xsl:otherwise><xsl:value-of select="'_'"/></xsl:otherwise>
        </xsl:choose>
      </xsl:variable>
      <xsl:call-template name="iterate">
          <xsl:with-param name="length" select="@quantity"/>
          <xsl:with-param name="display" select="$display"/>
      </xsl:call-template>
      <xsl:text>]</xsl:text>
    </span>
  </xsl:template>

  <xsl:template name="iterate">
    <xsl:param name="length" select="1"/>
    <xsl:param name="display" select="'_'"/>
    <xsl:value-of select="$display"/>
    <xsl:if test="$length > 1">
        <xsl:call-template name="iterate">
            <xsl:with-param name="length" select="$length - 1"/>
            <xsl:with-param name="display" select="$display"/>
        </xsl:call-template>
    </xsl:if>
  </xsl:template>
  
  <xsl:template match="tei:fw[@type='sig']">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <div class="sig {$class}"><xsl:apply-templates/></div>
  </xsl:template>
  <xsl:template match="tei:fw[@type='catch']">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <div class="catch {$class}"><xsl:apply-templates/></div>
  </xsl:template>
  <xsl:template match="tei:fw[@type='pagNum']">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <div class="pageNbr {$class}"><xsl:apply-templates/></div>
  </xsl:template>
  <xsl:template match="tei:fw[@type='runningHeader']">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <div class="runningHead centered italic {$class}"><xsl:apply-templates/></div>
  </xsl:template>

  <xsl:template match="tei:milestone[@prev]">
    <xsl:choose>
      <xsl:when test="following::tei:w[1][not(@prev)]">
        <span class="alignment stump">&#160;</span>
      </xsl:when>
      <xsl:otherwise>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="tei:list">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <div class="list {$class}"><xsl:apply-templates/></div>
  </xsl:template>
  <xsl:template match="tei:list//tei:head">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="head centered {$class}"><xsl:apply-templates/></span>
    <br/>
  </xsl:template>
  <xsl:template match="tei:item[contains(@rend,'column')]/tei:list">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <div class="column {$class}"><xsl:apply-templates/></div>
  </xsl:template>
  <xsl:template match="tei:item">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="item {$class}"><xsl:apply-templates/></span><br/>
  </xsl:template>
  <xsl:template match="tei:castItem">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="item {$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="tei:castGroup">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="{$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="tei:item[contains(@rend,'column')]">
    <xsl:apply-templates/>
  </xsl:template>
  <xsl:template match="tei:role[@rend]|tei:roleDesc[@rend]|tei:actor[@rend]">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="{$class}"><xsl:apply-templates/></span>
  </xsl:template>
  <xsl:template match="tei:roleDesc[@rend]">
    <xsl:variable name="class" select="translate(@rend,',',' ')" />
    <span class="{$class}"><xsl:apply-templates/></span>
  </xsl:template>

  <xsl:template match="tei:interpGrp"/>
  
  <xsl:template match="tei:mentioned">
    <span class="italic"><xsl:apply-templates/></span>
  </xsl:template>

  <xsl:template match="tei:div[ends-with( normalize-space( @type ), '_notes') ]">
    <br/>
    <hr/>
    <xsl:variable name="notesType" select="substring-before( @type,'_')"/>
    <xsl:variable name="notesType" select="concat( upper-case( substring( $notesType, 1, 1)), substring( $notesType, 2 ) )"/>
    <div class="sceneHeader" style="font-weight:bold;">
      <xsl:choose>
        <xsl:when test="head">
          <xsl:apply-templates select="head"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="$notesType"/> Notes
        </xsl:otherwise>
      </xsl:choose>      
    </div>
    <xsl:apply-templates select="p|list" mode="prose"/>
    <ol style="padding-left:0;">
      <xsl:apply-templates select="note"/>
    </ol>
  </xsl:template>
  <xsl:template match="tei:div[ends-with( normalize-space( @type ), '_notes') ]/tei:note">
    <xsl:variable name="target" select="normalize-space( @target )" />
    <xsl:variable name="tgt" select="translate($target,'#','')" />
    <xsl:variable name="lid" select="substring($target,2,88)" />
    <li id="note-{$lid}">
      <xsl:value-of select="@n"/>
      <a href="{$target}">
        <xsl:value-of select="id($tgt)/preceding::tei:lb[@n][1]/@n"/>
        <xsl:text> (</xsl:text>
        <xsl:value-of select="id($tgt)/preceding::tei:pb[@facs][1]/@facs"/>
        <xsl:text>)</xsl:text>        
      </a>:
      <xsl:choose>
        <xsl:when test="./tei:app/tei:lem/tei:corr"> 
          The regularized reading <i><xsl:value-of select="./tei:app/tei:lem"/></i>
          is amended from the original <i><xsl:value-of select="./tei:app/tei:rdg[contains(@resp,'#origEMED')]"/></i>.
        </xsl:when>
        <xsl:when test="./tei:app/tei:rdg/tei:gap"> 
          The regularized reading <i><xsl:value-of select="./tei:app/tei:lem"/></i>
          is supplied for the original <i><xsl:apply-templates select="./tei:app/tei:rdg[contains(@resp,'#origEMED')]"/></i>.
        </xsl:when>
        <xsl:when test="./tei:app/tei:rdg[not(contains(@resp,'#origEMED'))]"> 
          The regularized reading <i><xsl:value-of select="./tei:app/tei:lem"/></i>
          comes from the original <i><xsl:value-of select="./tei:app/tei:rdg[contains(@resp,'#origEMED')]"/></i>,
          though possible variants include <i><xsl:value-of select="./tei:app/tei:rdg[not(contains(@resp,'#origEMED'))]"/></i>.
        </xsl:when>
        <xsl:otherwise>
          <xsl:apply-templates/>
        </xsl:otherwise>
      </xsl:choose>
    </li>
  </xsl:template>
  <xsl:key name="noteTargets" match="tei:div[ends-with( normalize-space( @type ), '_notes') ]/tei:note" use="substring(@target,2)"/> 

</xsl:stylesheet>
